Index: test/mjsunit/debug-step.js |
diff --git a/test/mjsunit/debug-step.js b/test/mjsunit/debug-step.js |
index bfbea16380cf7396c5c3571c55a0ba9f707d12ab..6f5c8f410c10d623f596fdd3e2f1bbf0513c2c16 100644 |
--- a/test/mjsunit/debug-step.js |
+++ b/test/mjsunit/debug-step.js |
@@ -64,9 +64,9 @@ function f() { |
// Set a breakpoint on the for statement (line 1). |
bp1 = Debug.setBreakPoint(f, 1); |
// Check that performing 1000 steps will make i 499. |
var step_count = 1000; |
result = -1; |
f(); |
-assertEquals(332, result); |
+assertEquals(333, result); |
Debug.setListener(null); |
@@ -64,9 +64,9 @@ function f() { |
// Set a breakpoint on the for statement (line 1). |
bp1 = Debug.setBreakPoint(f, 1); |
-// Check that performing 1000 steps will make i 499. |
+// Check that performing 1000 steps will make i 333. |
var step_count = 1000; |
result = -1; |